"use strict";
/**
 * Copyright(c) Microsoft Corporation.All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const botbuilder_dialogs_1 = require("botbuilder-dialogs");
const interruptionAction_1 = require("./interruptionAction");
class InterruptableDialog extends botbuilder_dialogs_1.ComponentDialog {
    // Constructor
    constructor(dialogId, telemetryClient) {
        super(dialogId);
        this.primaryDialogName = dialogId;
        this.telemetryClient = telemetryClient;
    }
    async onBeginDialog(dc, options) {
        if (dc.dialogs.find(this.primaryDialogName) !== undefined) {
            // Overrides default behavior which starts the first dialog added to the stack (i.e. Cancel waterfall)
            return dc.beginDialog(this.primaryDialogName, options);
        }
        else {
            // If we don't have a matching dialog, start the initial dialog
            return dc.beginDialog(this.initialDialogId, options);
        }
    }
    async onContinueDialogAsync(dc) {
        const status = await this.onInterruptDialog(dc);
        if (status === interruptionAction_1.InterruptionAction.MessageSentToUser) {
            // Resume the waiting dialog after interruption
            await dc.repromptDialog();
            return botbuilder_dialogs_1.Dialog.EndOfTurn;
        }
        else if (status === interruptionAction_1.InterruptionAction.StartedDialog) {
            // Stack is already waiting for a response, shelve inner stack
            return botbuilder_dialogs_1.Dialog.EndOfTurn;
        }
        return super.onContinueDialog(dc);
    }
}
exports.InterruptableDialog = InterruptableDialog;
//# sourceMappingURL=interruptableDialog.js.map