/**
 * Copyright(c) Microsoft Corporation.All rights reserved.
 * Licensed under the MIT License.
 */
import { BotTelemetryClient } from 'botbuilder-core';
import { DialogContext, DialogTurnResult } from 'botbuilder-dialogs';
import { InterruptableDialog } from './interruptableDialog';
import { InterruptionAction } from './interruptionAction';
export declare abstract class RouterDialog extends InterruptableDialog {
    constructor(dialogId: string, telemetryClient: BotTelemetryClient);
    protected onBeginDialog(innerDc: DialogContext, options: object): Promise<DialogTurnResult>;
    protected onContinueDialog(innerDc: DialogContext): Promise<DialogTurnResult>;
    /**
     * Called when the inner dialog stack is empty.
     * @param innerDC - The dialog context for the component.
     * @returns A Promise representing the asynchronous operation.
     */
    protected abstract route(innerDc: DialogContext): Promise<void>;
    /**
     * Called when the inner dialog stack is complete.
     * @param innerDC - The dialog context for the component.
     * @param result - The dialog result when inner dialog completed.
     * @returns A Promise representing the asynchronous operation.
     */
    protected complete(innerDc: DialogContext, result: DialogTurnResult): Promise<void>;
    /**
     * Called when an event activity is received.
     * @param innerDC - The dialog context for the component.
     * @returns A Promise representing the asynchronous operation.
     */
    protected onEvent(innerDc: DialogContext): Promise<void>;
    /**
     * Called when a system activity is received.
     * @param innerDC - The dialog context for the component.
     * @returns A Promise representing the asynchronous operation.
     */
    protected onSystemMessage(innerDc: DialogContext): Promise<void>;
    /**
     * Called when a conversation update activity is received.
     * @param innerDC - The dialog context for the component.
     * @returns A Promise representing the asynchronous operation.
     */
    protected onStart(innerDc: DialogContext): Promise<void>;
    protected onInterruptDialog(dc: DialogContext): Promise<InterruptionAction>;
}
