"use strict";
/**
 * Copyright(c) Microsoft Corporation.All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const botframework_schema_1 = require("botframework-schema");
var ActivityExtensions;
(function (ActivityExtensions) {
    function createReply(source, text, local) {
        const reply = text || '';
        return {
            channelId: source.channelId,
            conversation: source.conversation,
            from: source.recipient,
            label: source.label,
            locale: local,
            callerId: source.callerId,
            recipient: source.from,
            replyToId: source.id,
            serviceUrl: source.serviceUrl,
            text: reply,
            timestamp: new Date(),
            type: botframework_schema_1.ActivityTypes.Message,
            valueType: source.valueType,
            localTimezone: source.localTimezone,
            listenFor: source.listenFor,
            semanticAction: source.semanticAction
        };
    }
    ActivityExtensions.createReply = createReply;
    function getContinuationActivity(source) {
        if (source === undefined) {
            throw new Error('source needs to be defined');
        }
        return {
            type: botframework_schema_1.ActivityTypes.Event,
            name: 'ContinueConversation',
            channelId: source.channelId,
            serviceUrl: source.serviceUrl,
            conversation: source.conversation,
            recipient: source.bot,
            from: source.user,
            relatesTo: source
        };
    }
    ActivityExtensions.getContinuationActivity = getContinuationActivity;
    function isStartActivity(activity) {
        switch (activity.channelId) {
            case 'skype': {
                if (activity.type === botframework_schema_1.ActivityTypes.ContactRelationUpdate && activity.action === 'add') {
                    return true;
                }
                return false;
            }
            case 'directline':
            case 'emulator':
            case 'webchat':
            case 'msteams':
            case 'directlinespeech':
            case 'test': {
                if (activity.type === botframework_schema_1.ActivityTypes.ConversationUpdate) {
                    // When bot is added to the conversation (triggers start only once per conversation)
                    if (activity.membersAdded !== undefined &&
                        activity.membersAdded.some((m) => m.id === activity.recipient.id)) {
                        return true;
                    }
                }
                return false;
            }
            default:
                return false;
        }
    }
    ActivityExtensions.isStartActivity = isStartActivity;
})(ActivityExtensions = exports.ActivityExtensions || (exports.ActivityExtensions = {}));
//# sourceMappingURL=activityExtensions.js.map