"use strict";
/**
 * Copyright(c) Microsoft Corporation.All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const dayjs = require("dayjs");
const i18next_1 = require("i18next");
var DateTimeExtensions;
(function (DateTimeExtensions) {
    let currentLocale;
    async function importLocale(locale) {
        try {
            const localeImport = locale === 'zh' ?
                `../resources/customizeLocale/zh` :
                `dayjs/locale/${locale}`;
            await Promise.resolve().then(() => require(localeImport));
        }
        catch (err) {
            throw new Error(`There was an error during the import of the locale:${locale}, Error:${err}`);
        }
    }
    async function toSpeechDateString(date, includePrefix = false) {
        const locale = i18next_1.default.language;
        if (currentLocale !== locale) {
            currentLocale = locale;
            await importLocale(locale);
        }
        const utcDate = new Date();
        utcDate.setHours(date.getHours());
        utcDate.setMinutes(date.getMinutes());
        utcDate.setSeconds(date.getSeconds());
        if (date.toUTCString() === utcDate.toUTCString()) {
            return i18next_1.default.t('common:today');
        }
        const nextDate = new Date();
        nextDate.setDate(nextDate.getDate() + 1);
        nextDate.setHours(date.getHours());
        nextDate.setMinutes(date.getMinutes());
        nextDate.setSeconds(date.getSeconds());
        if (date.toUTCString() === nextDate.toUTCString()) {
            return i18next_1.default.t('common:tomorrow');
        }
        const prefix = i18next_1.default.t('common:spokenDatePrefix');
        if (includePrefix && prefix) {
            return `${prefix} ${dayjs(date)
                .locale(locale)
                .format(i18next_1.default.t('common:spokenDateFormat'))}`;
        }
        return dayjs(date)
            .locale(locale)
            .format(i18next_1.default.t('common:spokenDateFormat'));
    }
    DateTimeExtensions.toSpeechDateString = toSpeechDateString;
    function toSpeechTimeString(date, includePrefix = false) {
        if (includePrefix) {
            const prefix = date.getHours() === 1
                ? i18next_1.default.t('common:spokenTimePrefixOne')
                : i18next_1.default.t('common:spokenTimePrefixMoreThanOne');
            if (prefix) {
                return `${prefix} ${date.toLocaleTimeString()}`;
            }
        }
        return date.toLocaleTimeString();
    }
    DateTimeExtensions.toSpeechTimeString = toSpeechTimeString;
})(DateTimeExtensions = exports.DateTimeExtensions || (exports.DateTimeExtensions = {}));
//# sourceMappingURL=dateTimeExtensions.js.map