"use strict";
/**
 * Copyright(c) Microsoft Corporation.All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const i18next_1 = require("i18next");
var ListExtensions;
(function (ListExtensions) {
    /**
     * Converts a list into a string that can be used in speech.
     * @param list The list to be converted.
     * @param finalSeparator The separator to be used for the last element of the list ("and" or "or" for example).
     * @param stringAccessor A method that can be used to extract the elements from the list if it is a complex type.
     * @returns A comma separated string with the elements in the list.
     */
    function toSpeechString(list, finalSeparator, stringAccessor) {
        // If stringAccessor is undefined, use JSON.stringify to convert the T value
        const itemAccessor = stringAccessor || JSON.stringify;
        let speech = '';
        let separator = '';
        const listCount = list.length;
        list.forEach((listItem, index) => {
            if (typeof listItem === 'string') {
                speech = speech.concat(listItem);
            }
            else {
                speech = speech.concat(itemAccessor(listItem));
            }
            if (listCount > 1) {
                if (index === listCount - 2) {
                    separator = i18next_1.default.t('common:separatorFormat')
                        .replace('{0}', finalSeparator);
                }
                else {
                    separator = index !== listCount - 1 ? ', ' : '';
                }
                speech = speech + separator;
            }
        });
        return speech;
    }
    ListExtensions.toSpeechString = toSpeechString;
})(ListExtensions = exports.ListExtensions || (exports.ListExtensions = {}));
//# sourceMappingURL=listExtensions.js.map