"use strict";
/**
 * Copyright(c) Microsoft Corporation.All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const botbuilder_1 = require("botbuilder");
class ConsoleOutputMiddleware {
    async onTurn(context, next) {
        this.logActivity('', context.activity);
        context.onSendActivities(this.onSendActivities.bind(this));
        await next();
    }
    static getTextOrSpeak(messageActivity) {
        if (messageActivity.text === undefined || messageActivity.text === '') {
            return messageActivity.speak || '';
        }
        return messageActivity.text;
    }
    async onSendActivities(context, activities, next) {
        activities.forEach((response) => {
            this.logActivity('', response);
        });
        return next();
    }
    logActivity(prefix, contextActivity) {
        this.log('');
        if (contextActivity.type === botbuilder_1.ActivityTypes.Message) {
            const messageActivity = contextActivity;
            this.log(`${prefix} [${Date.now()}] ${ConsoleOutputMiddleware.getTextOrSpeak(messageActivity)}`);
        }
        else if (contextActivity.type === botbuilder_1.ActivityTypes.Event) {
            const eventActivity = contextActivity;
            this.log(`${prefix} [${Date.now()}] ${eventActivity.name}`);
        }
        else {
            this.log(`${prefix} ${contextActivity.type}: [${Date.now()}]`);
        }
    }
    log(message) {
        // tslint:disable-next-line:no-console
        console.log(message);
    }
}
exports.ConsoleOutputMiddleware = ConsoleOutputMiddleware;
//# sourceMappingURL=consoleOutputMiddleware.js.map