/**
 * Copyright(c) Microsoft Corporation.All rights reserved.
 * Licensed under the MIT License.
 */
import { Middleware, TurnContext } from 'botbuilder';
export declare class ContentModeratorMiddleware implements Middleware {
    /**
     * Key for Text Moderator result in Bot Context dictionary.
     */
    readonly serviceName: string;
    /**
     * Key for Text Moderator result in Bot Context dictionary.
     */
    readonly textModeratorResultKey: string;
    /**
     * Content Moderator service key.
     */
    readonly subscriptionKey: string;
    /**
     * Content Moderator service region.
     */
    readonly region: string;
    /**
     * Initializes a new instance of the "ContentModeratorMiddleware" class.
     * @param subscriptionKey Azure Service Key.
     * @param region Azure Service Region.
     */
    constructor(subscriptionKey: string, region: string);
    /**
     * Analyzes activity text with Content Moderator and adds result to Bot Context. Run on each turn of the conversation.
     * @param context The Bot Context object.
     * @param next The next middleware component to run.
     */
    onTurn(context: TurnContext, next: () => Promise<void>): Promise<void>;
    private textToReadable;
}
