"use strict";
/**
 * Copyright(c) Microsoft Corporation.All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const botframework_schema_1 = require("botframework-schema");
class EventDebuggerMiddleware {
    async onTurn(turnContext, next) {
        const activity = turnContext.activity;
        if (activity.type === botframework_schema_1.ActivityTypes.Message) {
            const text = activity.text;
            const value = JSON.stringify(activity.value);
            if (text && text.startsWith('/event:')) {
                const json = text.substr('/event:'.length);
                // eslint-disable-next-line @typescript-eslint/tslint/config
                const body = JSON.parse(json);
                turnContext.activity.type = botframework_schema_1.ActivityTypes.Event;
                turnContext.activity.name = body.name || turnContext.activity.name;
                turnContext.activity.text = body.text || turnContext.activity.text;
                turnContext.activity.value = body.value || turnContext.activity.value;
            }
            if (value && value.includes('event')) {
                // eslint-disable-next-line @typescript-eslint/tslint/config
                const body = JSON.parse(value);
                turnContext.activity.type = botframework_schema_1.ActivityTypes.Event;
                if (body.event !== undefined) {
                    if (body.event.name !== undefined) {
                        turnContext.activity.name = body.event.name;
                    }
                    if (body.event.text !== undefined) {
                        turnContext.activity.text = body.event.text;
                    }
                    if (body.event.value !== undefined) {
                        turnContext.activity.value = body.event.value;
                    }
                }
            }
        }
        return next();
    }
}
exports.EventDebuggerMiddleware = EventDebuggerMiddleware;
//# sourceMappingURL=eventDebuggerMiddleware.js.map