/**
 * Copyright(c) Microsoft Corporation.All rights reserved.
 * Licensed under the MIT License.
 */
import { Middleware, TurnContext } from 'botbuilder';
/**
 * Set Speech Synthesis Markup Language (SSML) on an Activity's Speak property with locale and voice input.
 */
export declare class SetSpeakMiddleware implements Middleware {
    private readonly locale;
    private readonly voiceFont;
    private readonly namespaceURI;
    constructor(locale?: string, voiceName?: string);
    /**
     * If outgoing Activities are messages and using the Direct Line Speech channel,
     * decorate the Speak property with an SSML formatted string.
     * @param context The Bot Context object.
     * @param next The next middleware component to run.
     */
    onTurn(context: TurnContext, next: () => Promise<void>): Promise<void>;
    private decodeSSML;
    private elementParse;
    private getLocalName;
    private createBaseElement;
    private addAttributeIfMissing;
    private updateAttributeIfPresent;
    private addVoiceElementIfMissing;
}
