"use strict";
/**
 * Copyright(c) Microsoft Corporation.All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const botbuilder_1 = require("botbuilder");
const util_1 = require("../util");
const proactiveModel_1 = require("./proactiveModel");
/**
 * A Middleware for saving the proactive model data
 * This middleware will refresh user's latest conversation reference and save it to state.
 */
class ProactiveStateMiddleware {
    constructor(proactiveState, proactiveStateAccessor) {
        this.proactiveState = proactiveState;
        this.proactiveStateAccessor = proactiveStateAccessor;
    }
    async onTurn(context, next) {
        const activity = context.activity;
        const fromRole = activity.from.role ? activity.from.role.toLowerCase() : '';
        if (fromRole === 'user') {
            const proactiveState = await this.proactiveStateAccessor.get(context, new proactiveModel_1.ProactiveModel());
            let data;
            const hashedUserId = util_1.MD5Util.computeHash(activity.from.id);
            const conversationReference = botbuilder_1.TurnContext.getConversationReference(activity);
            if (proactiveState[hashedUserId] !== undefined) {
                data = { conversation: conversationReference };
                proactiveState[hashedUserId] = { conversation: conversationReference };
            }
            else {
                data = { conversation: conversationReference };
            }
            proactiveState[hashedUserId] = data;
            await this.proactiveStateAccessor.set(context, proactiveState);
            await this.proactiveState.saveChanges(context);
        }
        await next();
    }
}
exports.ProactiveStateMiddleware = ProactiveStateMiddleware;
//# sourceMappingURL=proactiveStateMiddleware.js.map