"use strict";
/**
 * Copyright(c) Microsoft Corporation.All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const i18next_1 = require("i18next");
const listExtensions_1 = require("../extensions/listExtensions");
/**
 * Read order of list items.
 */
var ReadPreference;
(function (ReadPreference) {
    /**
     * First item, second item, third item, etc.
     */
    ReadPreference[ReadPreference["Enumeration"] = 0] = "Enumeration";
    /**
     * Latest item, second item, third item, etc.
     */
    ReadPreference[ReadPreference["Chronological"] = 1] = "Chronological";
})(ReadPreference = exports.ReadPreference || (exports.ReadPreference = {}));
var SpeechUtility;
(function (SpeechUtility) {
    function listToSpeechReadyString(toProcess, readOrder = ReadPreference.Enumeration, maxSize = 4) {
        let speakStrings = [];
        let parent = '';
        if (toProcess.choices !== undefined) {
            const selectOption = toProcess;
            const choices = selectOption.choices || [];
            speakStrings = choices.map((value) => typeof (value) === 'string' ? value : value.value);
            parent = typeof (selectOption.prompt) === 'string'
                ? (selectOption.prompt || '')
                : (selectOption.prompt ? (selectOption.prompt.text || '') : '');
        }
        else {
            const activity = toProcess;
            const attachments = activity.attachments || [];
            // eslint-disable-next-line @typescript-eslint/tslint/config
            speakStrings = attachments.map((value) => value.content.speak);
            parent = activity.speak || '';
        }
        return listToSpeech(parent, speakStrings, readOrder, maxSize);
    }
    SpeechUtility.listToSpeechReadyString = listToSpeechReadyString;
    function listToSpeech(parent, selectionStrings, readOrder, maxSize) {
        const result = `${parent} ` || '';
        const itemDetails = [];
        const readSize = Math.min(selectionStrings.length, maxSize);
        if (readSize === 1) {
            itemDetails.push(selectionStrings[0]);
        }
        else {
            for (let index = 0; index < readSize; index = index + 1) {
                let readFormat = '';
                if (index === 0) {
                    if (readOrder === ReadPreference.Chronological) {
                        readFormat = i18next_1.default.t('common:latestItem');
                    }
                    else {
                        readFormat = i18next_1.default.t('common:firstItem');
                    }
                }
                else {
                    if (index === readSize - 1) {
                        readFormat = i18next_1.default.t('common:lastItem');
                    }
                    else {
                        if (index === 1) {
                            readFormat = i18next_1.default.t('common:secondItem');
                        }
                        else if (index === 2) {
                            readFormat = i18next_1.default.t('common:thirdItem');
                        }
                        else if (index === 3) {
                            readFormat = i18next_1.default.t('common:fourthItem');
                        }
                    }
                }
                const selectionDetail = readFormat.replace('{0}', selectionStrings[index]);
                itemDetails.push(selectionDetail);
            }
        }
        return result + listExtensions_1.ListExtensions.toSpeechString(itemDetails, i18next_1.default.t('common:and'));
    }
})(SpeechUtility = exports.SpeechUtility || (exports.SpeechUtility = {}));
//# sourceMappingURL=speechUtility.js.map